<?php
/**
 * AlertyFast Settings Class
 * 
 * Handles settings operations for the AlertyFast plugin
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class AlertyFast_Settings {
    /**
     * Constructor
     */
    public function __construct() {
        // Initialize settings if not already set
        if (false === get_option('alertyfast_settings')) {
            $this->init_settings();
        }
    }

    /**
     * Initialize default settings
     */
    public function init_settings() {
        $default_settings = array(
            'api_key' => '',
            'new_order_notifications' => 'no',
            'new_order_phone' => '',
            'paid_order_notifications' => 'no',
            'paid_order_phone' => ''
        );
        
        update_option('alertyfast_settings', $default_settings);
    }

    /**
     * Get all settings
     * 
     * @return array The settings array
     */
    public function get_settings() {
        return get_option('alertyfast_settings', array());
    }

    /**
     * Get a specific setting
     * 
     * @param string $key The setting key
     * @param mixed $default Default value if setting doesn't exist
     * @return mixed The setting value
     */
    public function get_setting($key, $default = '') {
        $settings = $this->get_settings();
        return isset($settings[$key]) ? $settings[$key] : $default;
    }

    /**
     * Update a specific setting
     * 
     * @param string $key The setting key
     * @param mixed $value The setting value
     * @return bool True if setting was updated
     */
    public function update_setting($key, $value) {
        $settings = $this->get_settings();
        $settings[$key] = $value;
        return update_option('alertyfast_settings', $settings);
    }

    /**
     * Check if API key is valid and set
     * 
     * @return bool True if API key is set and valid
     */
    public function is_api_key_valid() {
        $api_key = $this->get_setting('api_key');
        return !empty($api_key);
    }
}

// Initialize settings class
$alertyfast_settings = new AlertyFast_Settings(); 